==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.ReportType
import com.pulumi.azurenative.costmanagement.kotlin.enums.TimeframeType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The definition of a report.
 * @property dataset Has definition for data in this report.
 * @property timePeriod Has time period for pulling data for the report.
 * @property timeframe The time frame for pulling data for the report. If custom, then a specific time period must be provided.
 * @property type The type of the report.
 */
public data class ReportDefinitionArgs(
    public val dataset: Output<ReportDatasetArgs>? = null,
    public val timePeriod: Output<ReportTimePeriodArgs>? = null,
    public val timeframe: Output<Either<String, TimeframeType>>,
    public val type: Output<Either<String, ReportType>>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs.builder()
            .dataset(dataset?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timePeriod(timePeriod?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timeframe(
                timeframe.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ReportDefinitionArgs].
 */
@PulumiTagMarker
public class ReportDefinitionArgsBuilder internal constructor() {
    private var dataset: Output<ReportDatasetArgs>? = null

    private var timePeriod: Output<ReportTimePeriodArgs>? = null

    private var timeframe: Output<Either<String, TimeframeType>>? = null

    private var type: Output<Either<String, ReportType>>? = null

    /**
     * @param value Has definition for data in this report.
     */
    @JvmName("tkdqimetdeablcfk")
    public suspend fun dataset(`value`: Output<ReportDatasetArgs>) {
        this.dataset = value
    }

    /**
     * @param value Has time period for pulling data for the report.
     */
    @JvmName("tdynrbyuqvucjqyf")
    public suspend fun timePeriod(`value`: Output<ReportTimePeriodArgs>) {
        this.timePeriod = value
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("fpomqpupnxuimshm")
    public suspend fun timeframe(`value`: Output<Either<String, TimeframeType>>) {
        this.timeframe = value
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("rveulkxprnbiuvnq")
    public suspend fun type(`value`: Output<Either<String, ReportType>>) {
        this.type = value
    }

    /**
     * @param value Has definition for data in this report.
     */
    @JvmName("lxgrhwqsdebjexya")
    public suspend fun dataset(`value`: ReportDatasetArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataset = mapped
    }

    /**
     * @param argument Has definition for data in this report.
     */
    @JvmName("btisttdxugifxyfk")
    public suspend fun dataset(argument: suspend ReportDatasetArgsBuilder.() -> Unit) {
        val toBeMapped = ReportDatasetArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dataset = mapped
    }

    /**
     * @param value Has time period for pulling data for the report.
     */
    @JvmName("quqelofxfccdvxnq")
    public suspend fun timePeriod(`value`: ReportTimePeriodArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timePeriod = mapped
    }

    /**
     * @param argument Has time period for pulling data for the report.
     */
    @JvmName("tnxtepiywlvupdcw")
    public suspend fun timePeriod(argument: suspend ReportTimePeriodArgsBuilder.() -> Unit) {
        val toBeMapped = ReportTimePeriodArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.timePeriod = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("fgjogweytilrehbr")
    public suspend fun timeframe(`value`: Either<String, TimeframeType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("dfukrikdctvtkyaf")
    public fun timeframe(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TimeframeType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("cpsalbagdckobtin")
    public fun timeframe(`value`: TimeframeType) {
        val toBeMapped = Either.ofRight<String, TimeframeType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("axhgielhxpsfuswf")
    public suspend fun type(`value`: Either<String, ReportType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("dfmfaktcaihpjjot")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReportType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("gbvutkjdcxqlgbjy")
    public fun type(`value`: ReportType) {
        val toBeMapped = Either.ofRight<String, ReportType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ReportDefinitionArgs = ReportDefinitionArgs(
        dataset = dataset,
        timePeriod = timePeriod,
        timeframe = timeframe ?: throw PulumiNullFieldException("timeframe"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.ReportType
import com.pulumi.azurenative.costmanagement.kotlin.enums.TimeframeType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The definition of a report.
 * @property dataset Has definition for data in this report.
 * @property timePeriod Has time period for pulling data for the report.
 * @property timeframe The time frame for pulling data for the report. If custom, then a specific time period must be provided.
 * @property type The type of the report.
 */
public data class ReportDefinitionArgs(
    public val dataset: Output<ReportDatasetArgs>? = null,
    public val timePeriod: Output<ReportTimePeriodArgs>? = null,
    public val timeframe: Output<Either<String, TimeframeType>>,
    public val type: Output<Either<String, ReportType>>,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportDefinitionArgs.builder()
            .dataset(dataset?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timePeriod(timePeriod?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .timeframe(
                timeframe.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ReportDefinitionArgs].
 */
@PulumiTagMarker
public class ReportDefinitionArgsBuilder internal constructor() {
    private var dataset: Output<ReportDatasetArgs>? = null

    private var timePeriod: Output<ReportTimePeriodArgs>? = null

    private var timeframe: Output<Either<String, TimeframeType>>? = null

    private var type: Output<Either<String, ReportType>>? = null

    /**
     * @param value Has definition for data in this report.
     */
    @JvmName("qjwkfjicuexpdiwe")
    public suspend fun dataset(`value`: Output<ReportDatasetArgs>) {
        this.dataset = value
    }

    /**
     * @param value Has time period for pulling data for the report.
     */
    @JvmName("nhfikquacyptlyis")
    public suspend fun timePeriod(`value`: Output<ReportTimePeriodArgs>) {
        this.timePeriod = value
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("ddggcukwiqnwvpio")
    public suspend fun timeframe(`value`: Output<Either<String, TimeframeType>>) {
        this.timeframe = value
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("pkvrlymptmvkjest")
    public suspend fun type(`value`: Output<Either<String, ReportType>>) {
        this.type = value
    }

    /**
     * @param value Has definition for data in this report.
     */
    @JvmName("ssscpythucrwsqgj")
    public suspend fun dataset(`value`: ReportDatasetArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataset = mapped
    }

    /**
     * @param argument Has definition for data in this report.
     */
    @JvmName("mrogbyknsalfpoec")
    public suspend fun dataset(argument: suspend ReportDatasetArgsBuilder.() -> Unit) {
        val toBeMapped = ReportDatasetArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.dataset = mapped
    }

    /**
     * @param value Has time period for pulling data for the report.
     */
    @JvmName("uvqedvtqiknokmvu")
    public suspend fun timePeriod(`value`: ReportTimePeriodArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timePeriod = mapped
    }

    /**
     * @param argument Has time period for pulling data for the report.
     */
    @JvmName("nppoupdpqtibnxhs")
    public suspend fun timePeriod(argument: suspend ReportTimePeriodArgsBuilder.() -> Unit) {
        val toBeMapped = ReportTimePeriodArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.timePeriod = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("lbjkefygbbxywodk")
    public suspend fun timeframe(`value`: Either<String, TimeframeType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("sownomstqwrsgddn")
    public fun timeframe(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TimeframeType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The time frame for pulling data for the report. If custom, then a specific time period must be provided.
     */
    @JvmName("pcxhvcoqvjgcevak")
    public fun timeframe(`value`: TimeframeType) {
        val toBeMapped = Either.ofRight<String, TimeframeType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.timeframe = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("duwpqvelmxbmnpge")
    public suspend fun type(`value`: Either<String, ReportType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("frurhxvwibdkgmbx")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReportType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value The type of the report.
     */
    @JvmName("ekwxrlrhdirdgahn")
    public fun type(`value`: ReportType) {
        val toBeMapped = Either.ofRight<String, ReportType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): ReportDefinitionArgs = ReportDefinitionArgs(
        dataset = dataset,
        timePeriod = timePeriod,
        timeframe = timeframe ?: throw PulumiNullFieldException("timeframe"),
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
